@@ -22,13 +22,13 @@ from tqdm import tqdm
 
 from splitgraph.config import SPLITGRAPH_META_SCHEMA, SPLITGRAPH_API_SCHEMA, SG_CMD_ASCII
 from splitgraph.core.common import Tracer
-from splitgraph.core.output import pluralise, truncate_list
 from splitgraph.core.fragment_manager import (
     get_temporary_table_id,
     get_chunk_groups,
     ExtraIndexInfo,
 )
 from splitgraph.core.indexing.range import quals_to_sql
+from splitgraph.core.output import pluralise, truncate_list
 from splitgraph.core.sql import select
 from splitgraph.core.types import TableSchema, Quals
 from splitgraph.engine import ResultShape
@@ -107,13 +107,20 @@ def create_foreign_table(
     table_name: str,
     schema_spec: TableSchema,
     internal_table_name: Optional[str] = None,
+    extra_options: Optional[Dict[str, str]] = None,
 ):
+    table_options = extra_options or {}
+    table_options.update({"table": internal_table_name or table_name})
+
+    table_opts, table_optvals = zip(*table_options.items())
+
     query = SQL("CREATE FOREIGN TABLE {}.{} (").format(Identifier(schema), Identifier(table_name))
     query += SQL(",".join("{} %s " % col.pg_type for col in schema_spec)).format(
         *(Identifier(col.name) for col in schema_spec)
     )
-    query += SQL(") SERVER {} OPTIONS (table %s);").format(Identifier(server))
-    args = [internal_table_name or table_name]
+    query += SQL(") SERVER {} OPTIONS (").format(Identifier(server))
+    query += SQL(",").join(Identifier(o) + SQL(" %s") for o in table_opts) + SQL(");")
+    args = list(table_optvals)
     for col in schema_spec:
         if col.comment:
             query += SQL("COMMENT ON COLUMN {}.{}.{} IS %s;").format(
